@@ -24,12 +24,15 @@ import codecs
 import logging
 import pickle
 from io import BytesIO
+from itertools import starmap
 
 from translate.misc.multistring import multistring
 from translate.storage.placeables import StringElem
 from translate.storage.placeables import parse as rich_parse
 from translate.storage.workflow import StateEnum as states
 
+logger = logging.getLogger(__name__)
+
 # Simple BOM based encoding detection
 ENCODING_BOMS = (
     (codecs.BOM_UTF8, "utf-8-sig"),
@@ -145,7 +148,7 @@ class TranslationUnit:
         return not self.__eq__(other)
 
     def __hash__(self):
-        return None
+        return hash((self.source, self.target, self.getid()))
 
     def __str__(self):
         """Converts to a string representation. Most often overriden by subclasses."""
@@ -407,6 +410,9 @@ class TranslationUnit:
         """
         return bool(self.source)
 
+    def marktranslatable(self, value: bool) -> None:
+        """Marks the unit as translateable or not."""
+
     @staticmethod
     def isfuzzy():
         """Indicates whether this unit is fuzzy."""
@@ -501,7 +507,7 @@ class TranslationUnit:
             if state_range[0] <= n < state_range[1]:
                 return state_id
         if self.STATE:
-            raise ValueError("No state containing value %s" % (n))
+            raise ValueError(f"No state containing value {n}")
         return n
 
     def get_state_n(self):
@@ -518,6 +524,28 @@ class TranslationUnit:
         current state(_n) of the unit from its current state.
         """
 
+    @staticmethod
+    def sync_plural_count(
+        target: list[str] | str | multistring, plural_tags: list[str]
+    ) -> list[str]:
+        """Ensure that plural count in string matches tags definition."""
+        # Get string list to handle, wrapping non multistring/list targets into a list.
+        if isinstance(target, multistring):
+            # Coerce all items to string, they might be multistrings
+            plural_strings = [str(string) for string in target.strings]
+        elif isinstance(target, list):
+            plural_strings = target
+        else:
+            plural_strings = [target]
+
+        # Add missing strings
+        missing = len(plural_tags) - len(plural_strings)
+        if missing:
+            plural_strings += [""] * missing
+
+        # Remove extra ones
+        return plural_strings[: len(plural_tags)]
+
 
 class TranslationStore:
     """Base class for stores for multiple translation units of type UnitClass."""
@@ -840,7 +868,7 @@ class TranslationStore:
             if encoding == self.encoding and suffix == "sig":
                 encodings.append(detected_encoding["encoding"])
             elif detected_encoding["encoding"] != self.encoding:
-                logging.warning(
+                logger.warning(
                     "trying to parse %s with encoding: %s but "
                     "detected encoding is %s (confidence: %s)",
                     self.filename,
@@ -891,6 +919,14 @@ class TranslationStore:
             fileobj = open(filename, "wb")
         self.savefile(fileobj)
 
+    @classmethod
+    def _from_handle(cls, storehandle):
+        storestring = storehandle.read()
+        newstore = cls.parsestring(storestring)
+        newstore.fileobj = storehandle
+        newstore._assignname()
+        return newstore
+
     @classmethod
     def parsefile(cls, storefile):
         """
@@ -898,16 +934,16 @@ class TranslationStore:
         to an object.
         """
         if isinstance(storefile, str):
-            storefile = open(storefile, "rb")
+            with open(storefile, "rb") as storehandle:
+                return cls._from_handle(storehandle)
         mode = getattr(storefile, "mode", "rb")
         # For some reason GzipFile returns 1, so we have to test for that here
         if mode == 1 or "r" in mode:
-            storestring = storefile.read()
+            newstore = cls._from_handle(storefile)
             storefile.close()
-            newstore = cls.parsestring(storestring)
-        else:
-            storestring = ""
-            newstore = cls()
+            return newstore
+
+        newstore = cls()
         newstore.fileobj = storefile
         newstore._assignname()
         return newstore
@@ -938,32 +974,47 @@ class UnitId:
                 return f"{self.INDEX_SEPARATOR}[{key}]"
             raise ValueError(f"Unsupported element: {element}")
 
-        return "".join(fmt(*part) for part in self.parts)
+        return "".join(starmap(fmt, self.parts))
 
     def extend(self, key, value):
         return self.__class__([*self.parts, (key, value)])
 
     @classmethod
-    def from_string(cls, text):
+    def from_key(cls, text: str) -> UnitId:
+        return cls([("key", text)])
+
+    @classmethod
+    def from_string(cls, text: str) -> UnitId:
         result = []
         # Strip possible leading separator
-        if text.startswith(cls.KEY_SEPARATOR):
-            text = text[len(cls.KEY_SEPARATOR) :]
+        text = text.removeprefix(cls.KEY_SEPARATOR)
         for item in text.split(cls.KEY_SEPARATOR):
             bracepos = item.find("[")
             endbracepos = item.find("]")
-            if bracepos != -1 and endbracepos != -1:
+            while (
+                (bracepos := item.find("[")) != -1
+                and (endbracepos := item.find("]")) != -1
+                and item[bracepos + 1 : endbracepos].isdigit()
+            ):
                 if bracepos > 0:
                     result.append(("key", item[:bracepos]))
                     item = item[bracepos:]
-                result.extend(
-                    ("index", int(pos))
-                    for pos in item.replace("[", " ").replace("]", " ").split()
-                )
-            else:
+                    endbracepos -= bracepos
+                    bracepos = 0
+                result.append(("index", int(item[bracepos + 1 : endbracepos])))
+                item = item[endbracepos + 1 :]
+            if item:
                 result.append(("key", item))
+        if not result:
+            result.append(("key", ""))
         return cls(result)
 
+    def __eq__(self, other):
+        return self.parts == other.parts
+
+    def __repr__(self):
+        return f"<UnitId:{self.parts}>"
+
 
 class DictUnit(TranslationUnit):
     IdClass = UnitId
