@@ -65,6 +65,7 @@ Todo:
 - Handle ``\u`` and other escapes in Unicode
 - Manage data type storage and conversion. True --> "True" --> True
 
+
 """
 
 import json
@@ -138,7 +139,7 @@ class BaseJsonUnit(base.DictUnit):
 class FlatUnitId(base.UnitId):
     @classmethod
     def from_string(cls, text):
-        key = text[1:] if text.startswith(".") else text
+        key = text.removeprefix(".")
         return cls([("key", key)])
 
 
@@ -254,7 +255,7 @@ class JsonNestedFile(JsonFile):
     UnitClass = JsonNestedUnit
 
 
-class WebExtensionJsonUnit(BaseJsonUnit):
+class WebExtensionJsonUnit(FlatJsonUnit):
     def storevalues(self, output):
         value = {"message": self.target}
         if self.notes:
@@ -286,13 +287,17 @@ class WebExtensionJsonFile(JsonFile):
         last_node=None,
     ):
         for item, value in data.items():
+            if isinstance(value, str):
+                raise base.ParseError(
+                    ValueError("File is not a valid WebExtension JSON file!")
+                )
             unit = self.UnitClass(
                 value.get("message", ""),
                 item,
                 value.get("description", ""),
                 value.get("placeholders", None),
             )
-            unit.setid(item)
+            unit.setid(item, unitid=self.UnitClass.IdClass.from_key(item))
             yield unit
 
 
@@ -349,8 +354,8 @@ class I18NextUnit(JsonNestedUnit):
             super().storevalues(output)
         else:
             if len(self.target.strings) > len(self._store.plural_tags):
-                self.target.strings = self.target.strings[
-                    : len(self._store.plural_tags)
+                self.target.extra_strings = self.target.extra_strings[
+                    : len(self._store.plural_tags) - 1
                 ]
             self._fixup_item()
             for i, value in enumerate(self.target.strings):
@@ -393,7 +398,7 @@ class I18NextFile(JsonNestedFile):
                 plurals = []
                 plural_base = ""
                 if k in plurals_simple or k + "_plural" in plurals_simple:
-                    plural_base = k[:-7] if k.endswith("_plural") else k
+                    plural_base = k.removesuffix("_plural")
                     plurals_simple.remove(plural_base)
                     plurals = [k, k + "_plural"]
                 elif "_" in k:
@@ -502,6 +507,20 @@ class I18NextV4File(JsonNestedFile):
             )
 
 
+class FlatI18NextV4Unit(I18NextV4Unit):
+    IdClass = FlatUnitId
+
+
+class FlatI18NextV4File(I18NextV4File):
+    """
+    Flat json file with support of i18next v4 format plurals.
+
+    See https://www.i18next.com/
+    """
+
+    UnitClass = FlatI18NextV4Unit
+
+
 class GoTextUnitId(base.UnitId):
     """Preserves id as stored in the JSON file."""
 
@@ -545,9 +564,7 @@ class GoTextJsonUnit(BaseJsonUnit):
     def getvalue(self):
         target = self.target
         if isinstance(target, multistring):
-            strings = list(target.strings)
-            if len(self._store.plural_tags) > len(target.strings):
-                strings += [""] * (len(self._store.plural_tags) - len(target.strings))
+            strings = self.sync_plural_count(target, self._store.plural_tags)
             target = {
                 "select": {
                     "feature": "plural",
@@ -653,15 +670,13 @@ class GoTextJsonFile(JsonFile):
         out.write(b"\n")
 
 
-class GoI18NJsonUnit(BaseJsonUnit):
+class GoI18NJsonUnit(FlatJsonUnit):
     ID_FORMAT = "{}"
 
     def getvalue(self):
         target = self.target
         if isinstance(target, multistring):
-            strings = list(target.strings)
-            if len(self._store.plural_tags) > len(target.strings):
-                strings += [""] * (len(self._store.plural_tags) - len(target.strings))
+            strings = self.sync_plural_count(target, self._store.plural_tags)
             target = {
                 plural: strings[offset]
                 for offset, plural in enumerate(self._store.plural_tags)
@@ -719,7 +734,8 @@ class GoI18NJsonFile(JsonFile):
                 value.get("id", ""),
                 value.get("description", ""),
             )
-            unit.setid(value.get("id", ""))
+            item = value.get("id", "")
+            unit.setid(item, unitid=self.UnitClass.IdClass.from_key(item))
             yield unit
 
     def serialize(self, out):
@@ -728,7 +744,7 @@ class GoI18NJsonFile(JsonFile):
         out.write(b"\n")
 
 
-class GoI18NV2JsonUnit(BaseJsonUnit):
+class GoI18NV2JsonUnit(FlatJsonUnit):
     ID_FORMAT = "{}"
 
     def converttarget(self):
@@ -742,9 +758,7 @@ class GoI18NV2JsonUnit(BaseJsonUnit):
         if self.notes:
             target["description"] = self.notes
 
-        strings = self.target.strings
-        if len(self._store.plural_tags) > len(strings):
-            strings += [""] * (len(self._store.plural_tags) - len(target.strings))
+        strings = self.sync_plural_count(self.target, self._store.plural_tags)
         for offset, plural in enumerate(self._store.plural_tags):
             target[plural] = strings[offset]
 
@@ -793,11 +807,11 @@ class GoI18NV2JsonFile(JsonFile):
                     id,
                     value.get("description", ""),
                 )
-            unit.setid(id)
+            unit.setid(id, unitid=self.UnitClass.IdClass.from_key(id))
             yield unit
 
 
-class ARBJsonUnit(BaseJsonUnit):
+class ARBJsonUnit(FlatJsonUnit):
     ID_FORMAT = "{}"
 
     def __init__(
@@ -874,11 +888,11 @@ class ARBJsonFile(JsonFile):
                 metadata.get("placeholders", None),
                 metadata=metadata,
             )
-            unit.setid(item)
+            unit.setid(item, unitid=self.UnitClass.IdClass.from_key(item))
             yield unit
 
 
-class FormatJSJsonUnit(BaseJsonUnit):
+class FormatJSJsonUnit(FlatJsonUnit):
     def storevalues(self, output):
         value = {"defaultMessage": self.target}
         if self.notes:
@@ -892,7 +906,7 @@ class FormatJSJsonFile(JsonFile):
 
     See following URLs for doc:
 
-    https://formatjs.io/docs/getting-started/message-extraction/
+    https://formatjs.github.io/docs/getting-started/message-extraction/
     """
 
     UnitClass = FormatJSJsonUnit
@@ -912,5 +926,5 @@ class FormatJSJsonFile(JsonFile):
                 item,
                 value.get("description", ""),
             )
-            unit.setid(item)
+            unit.setid(item, unitid=self.UnitClass.IdClass.from_key(item))
             yield unit
