@@ -64,7 +64,7 @@ def normalizefilename(filename):
 
 def makekey(ookey, long_keys):
     """
-    converts an oo key tuple into a unique identifier.
+    Converts an oo key tuple into a unique identifier.
 
     :param ookey: an oo key
     :type ookey: tuple
@@ -155,9 +155,9 @@ def escape_help_text(text):
             "embedvar",
             "alt",
         ]:
-            if tag.startswith("<%s" % escape_tag) or tag == "</%s>" % escape_tag:
+            if tag.startswith(f"<{escape_tag}") or tag == f"</{escape_tag}>":
                 escapethistag = True
-        if tag in ["<br/>", "<help-id-missing/>"]:
+        if tag in {"<br/>", "<help-id-missing/>"}:
             escapethistag = True
         if escapethistag:
             escaped_tag = ("\\<" + tag[1:-1] + "\\>").replace('"', '\\"')
@@ -210,7 +210,7 @@ class ooline:
             )
             newparts = list(parts)
             if len(newparts) < 15:
-                newparts = newparts + [""] * (15 - len(newparts))
+                newparts += [""] * (15 - len(newparts))
             else:
                 newparts = newparts[:15]
             parts = tuple(newparts)
@@ -417,18 +417,16 @@ class oomultifile:
 
     def createsubfileindex(self):
         """Reads in all the lines and works out the subfiles."""
-        linenum = 0
-        for line in self.multifile:
+        for linenum, line in enumerate(self.multifile):
             subfile = self.getsubfilename(line)
             if subfile not in self.subfilelines:
                 self.subfilelines[subfile] = []
             self.subfilelines[subfile].append(linenum)
-            linenum += 1
 
     def getsubfilename(self, line):
         """Looks up the subfile name for the line."""
         if line.count("\t") < 2:
-            raise ValueError("invalid tab-delimited line: %r" % line)
+            raise ValueError(f"invalid tab-delimited line: {line!r}")
         lineparts = line.split("\t", 2)
         module, filename = lineparts[0], lineparts[1]
         if self.multifilestyle == "onefile":
@@ -457,12 +455,10 @@ class oomultifile:
         """Returns the list of lines matching the subfile."""
         lines = []
         requiredlines = dict.fromkeys(self.subfilelines[subfile])
-        linenum = 0
         self.multifile.seek(0)
-        for line in self.multifile:
+        for linenum, line in enumerate(self.multifile):
             if linenum in requiredlines:
                 lines.append(line)
-            linenum += 1
         return "".join(lines)
 
     def openinputfile(self, subfile):
